@@ -1,4 +1,5 @@
-import json, re
+import json
+import re
 
 try:
     from urllib import quote_plus
@@ -78,10 +79,15 @@ class SamWatchlists(CreateableResource,
 class SlackUsers(CreateableResource,
                  RetrieveableResource,
                  UpdateableResource):
-    pass
+    @classmethod
+    def get_all(cls, team_id, token):
+        url = "%sall/?team_id=%s" % (cls.get_object_url(), team_id)
+        requestor = api_requestor.ApiRequestor(token=token)
+        return json.loads(requestor.get(url).content)
 
 
-class SlackTeams(RetrieveableResource):
+class SlackTeams(RetrieveableResource,
+                 UpdateableResource):
     @classmethod
     def save_search_api_key(cls, oid, token, search_index, api_key):
         url = "%s%s/save_search_key/" % (cls.get_object_url(), oid)
@@ -90,3 +96,8 @@ class SlackTeams(RetrieveableResource):
             'search_index': search_index,
             'api_key': api_key
         }).content)
+
+
+class OneTimeTokens(CreateableResource,
+                    RetrieveableResource):
+    pass
